@@ -7,6 +7,14 @@ use 5.010;
 
 use namespace::autoclean;
 use Moose::Role;
+with qw(MooseX::Getopt::Meta::Attribute::Trait);
+
+
+has 'cmd_tags' => (
+    is          => 'rw',
+    isa         => 'ArrayRef[Str]',
+    predicate   => 'has_cmd_tags',
+);
 
 {
     package Moose::Meta::Attribute::Custom::Trait::AppOption;
