@@ -70,7 +70,7 @@ sub _build_app_commands {
 }
 
 sub proto_command {
-    my ($self,$command_class) = @_;
+    my ($self) = @_;
     
     my $opt_parser = Getopt::Long::Parser->new( 
         config => [ qw( no_auto_help pass_through ) ] 
@@ -370,12 +370,6 @@ sub command_usage_global {
     return @usage;
 }
 
-
-#{
-#    package Moose::Meta::Class::Custom::Trait::AppBase;
-#    sub register_implementation { 'MooseX::App::Meta::Role::Class::Base' }
-#}
-
 1;
 
 __END__
@@ -452,6 +446,12 @@ Returns a list of attribute documentations for a given meta class.
 
 Returns a name and description for a given meta attribute class.
 
+=head2 command_usage_attribute_tags
+
+ my (@tags) = $meta->command_usage_attribute_tags($metaattribute);
+
+Returns a list of tags for the given attribute.
+
 =head2 command_usage_attribute_name
 
  my ($name,$description) = $meta->command_usage_attribute_name($metaattribute);
@@ -502,4 +502,16 @@ Returns a hashref of command name and command class.
 
 Returns a list of command names matching the user input
 
+=head2 proto_command
+
+ my $result = $meta->proto_command();
+
+Returns the proto command command-line options.
+
+=head2 proto_options
+
+ my @getopt_options = $meta->proto_command($result_hashref);
+
+Sets the GetOpt::Long options for the proto command
+
 =cut
